@@ -4,8 +4,8 @@ from matplotlib.path import Path
 
 class BinaryRenderer:
 
-    def __init__(self, size):
-        self.map = np.zeros(size, dtype=bool)
+    def __init__(self, size, fill_value: bool = False):
+        self.map = np.full(size, fill_value=fill_value, dtype=bool)
 
         self.xx, self.yy = np.meshgrid(range(size[1]), range(size[0]))
         self.xy = np.vstack((self.xx.flatten(), self.yy.flatten())).T
@@ -21,6 +21,8 @@ class BinaryRenderer:
         self.map[y0:y1, x0:x1] = roi
 
     def polygon(self, points, value=True):
+        if len(points) == 0:
+            return
         x0 = max(int(points[:, 0].min()), 0)
         y0 = max(int(points[:, 1].min()), 0)
         x1 = min(int(points[:, 0].max()) + 2, self.map.shape[1] - 1)
