@@ -1,5 +1,6 @@
 import abc
 import logging
+from typing import Optional
 
 from ..world import World
 from .app_controls import AppControls
@@ -11,7 +12,7 @@ class Hardware(abc.ABC):
         self.world = world
         self.name = __name__[:-8] + self.__class__.__name__
         self.log = logging.getLogger(self.name)
-        self.app_controls: AppControls = None
+        self.app_controls: Optional[AppControls] = None
 
     @abc.abstractmethod
     async def configure(self):
