@@ -1,4 +1,3 @@
-import numpy as np
 from ..world import Velocity, World
 from .hardware import Hardware
 
@@ -11,24 +10,27 @@ class SimulatedHardware(Hardware):
         self.angular_velocity: float = 0
 
     async def configure(self):
+        await super().configure()
         raise Exception('there is no communication for configuring hardware')
 
     async def restart(self):
+        await super().restart()
         raise Exception('there is no communication for restarting hardware')
 
     async def drive(self, linear: float, angular: float):
+        await super().drive(linear, angular)
         self.linear_velocity = linear
         self.angular_velocity = angular
 
     async def stop(self):
+        await super().stop()
         self.linear_velocity = 0
         self.angular_velocity = 0
 
     async def update(self):
+        await super().update()
         self.world.robot.odometry.append(Velocity(
             linear=self.linear_velocity,
             angular=self.angular_velocity,
             time=self.world.time,
         ))
-        self.world.robot.battery = 25.0 + np.sin(0.1 * self.world.time) + 0.02 * np.random.randn()
-        self.world.robot.temperature = np.random.uniform(34, 35)
