@@ -14,5 +14,6 @@ from .path_object import PathObject as path_object
 from .profiler import create_profiler
 from .pyloot_page import PylootPage as pyloot_page
 from .robot_object import RobotObject as robot_object
-from .settings import update_interval
+from .settings import Settings as settings
+from .videos_page import VideosPage as videos_page
 from .wifi import wifi_button
